/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome:  7810_PLASTPS.SQL
REVISA_QTDE (SQL SERVER)
Descrio: Alterao automtica das quantidades dos produtos das receitas

Parmetros de entrada:
P_NRLISTA - Cdigo da tabela LISTA com chaves dos pratos
(CDLISTA = CDFILAUXPRAT + CDPRATO)
P_IDTIPORECE - Tipo da receita (P, L ou S)
P_IDOPCAO - P - percentual ou G - Gramagem
P_VRVALOR - valor informado pelo usurio conforme opcao (percentual ou gramagem)
P_CDFILIAL - filial...
P_CDSERVFILI - ...e servio da receita


Criao:

Dmaso - 25/10/2005
(solic. 24278)

*/
IF EXISTS(SELECT name FROM sysobjects
          WHERE name = 'REVISA_QTDE' AND type = 'P')
  DROP PROCEDURE REVISA_QTDE
  GO

CREATE PROCEDURE REVISA_QTDE
    @P_NRLISTA      VARCHAR(10),
    @P_IDTIPORECE   VARCHAR(1),
    @P_IDOPCAO      VARCHAR(1),
    @P_VRVALOR      NUMERIC(15,5),
    @P_CDFILIAL     VARCHAR(4),
    @P_CDSERVFILI   VARCHAR(5),
    @P_CDFILCENTPME VARCHAR(4),
    @P_CDTIPOCARD   VARCHAR(10)
AS
   DECLARE @V_SOMARECE NUMERIC(15,5);
   DECLARE @V_CDPRATO VARCHAR(10);
   DECLARE @V_CDFILAUXPRAT VARCHAR(4);
   DECLARE @V_COUNT NUMERIC(15,5);
   DECLARE @V_COUNTP NUMERIC(15,5);

BEGIN
   /* LOOP DA LISTA DE PRATOS */
   DECLARE C_LST CURSOR FOR
      select CDPRATO, CDFILAUXPRAT
      from LISTA, PRATO
      where
         NRLISTA = @P_NRLISTA and
         CDLISTA = CDFILAUXPRAT+CDPRATO;
   OPEN C_LST;
   FETCH NEXT FROM C_LST INTO @V_CDPRATO, @V_CDFILAUXPRAT;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      IF @P_IDTIPORECE = 'P' BEGIN
      /* Atualiza qtdes da receita conforme valor informado */
         IF @P_IDOPCAO = 'P' BEGIN
            SELECT @V_COUNT = ISNULL(ROUND(SUM(QTPADRAOPRAT), 5), 0)
            FROM PRATPADR
            WHERE
               CDFILAUXPRAT = @V_CDFILAUXPRAT and
               CDPRATO      = @V_CDPRATO;
            IF (@V_COUNT > 0) BEGIN
               update
                  PRATPADR
               set
                  QTPADRAOPRAT = ROUND((ISNULL(QTPADRAOPRAT, 1) * @P_VRVALOR), 5)
               where
                  CDFILAUXPRAT = @V_CDFILAUXPRAT and
                  CDPRATO      = @V_CDPRATO;
              update RECEPADR
              set
                QTPRODPRAT   = ROUND(QTPRODPRAT   * @P_VRVALOR, 5),
                QTUNIDESTPR  = ROUND(QTUNIDESTPR  * @P_VRVALOR, 5),
                QTBRUTAPR    = ROUND(QTBRUTAPR    * @P_VRVALOR, 5),
                QTBRUTAPRUNR = ROUND(QTBRUTAPRUNR * @P_VRVALOR, 5),
                QTCALCNUTRPR = ROUND(QTCALCNUTRPR * @P_VRVALOR, 5)
              where
                CDFILAUXPRAT = @V_CDFILAUXPRAT and
                CDPRATO      = @V_CDPRATO      and
                ISNULL(IDQTDEFIXPR,'N')  = 'N'       and
                (QTPRODPRAT   * @P_VRVALOR) >= 0.00001 and
                (QTBRUTAPR    * @P_VRVALOR) >= 0.00001;
            END;
         END
         ELSE BEGIN
            IF @P_IDOPCAO = 'G' BEGIN
               select @V_SOMARECE = ISNULL(ROUND(SUM(QTPADRAOPRAT), 5), 0)
               from PRATPADR
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO;
               
             select @V_COUNTP = COUNT(CDPRATO)
               from PRATPADR
              where
                  CDFILAUXPRAT = @V_CDFILAUXPRAT and
                  CDPRATO      = @V_CDPRATO;

               IF (@V_COUNTP = 0) BEGIN
                  INSERT INTO PRATPADR
                         (CDFILAUXPRAT, CDPRATO, QTPADRAOPRAT)
                  VALUES (@V_CDFILAUXPRAT, @V_CDPRATO, ROUND(@P_VRVALOR, 5));
               END
               ELSE BEGIN
                  UPDATE PRATPADR
                     SET QTPADRAOPRAT = ROUND(@P_VRVALOR, 5)
                   WHERE CDFILAUXPRAT = @V_CDFILAUXPRAT 
                     AND CDPRATO      = @V_CDPRATO;
               END;

               IF (@V_SOMARECE > 0) BEGIN
                  update
                     PRATPADR
                  set
                     QTPADRAOPRAT = ROUND(@P_VRVALOR, 5)
                  where
                     CDFILAUXPRAT = @V_CDFILAUXPRAT and
                     CDPRATO      = @V_CDPRATO;
                  update RECEPADR
                  set
                    QTPRODPRAT   = ROUND(((@P_VRVALOR * QTPRODPRAT  ) / @V_SOMARECE), 5),
                    QTUNIDESTPR  = ROUND(((@P_VRVALOR * QTUNIDESTPR ) / @V_SOMARECE), 5),
                    QTBRUTAPR    = ROUND(((@P_VRVALOR * QTBRUTAPR   ) / @V_SOMARECE), 5),
                    QTBRUTAPRUNR = ROUND(((@P_VRVALOR * QTBRUTAPRUNR) / @V_SOMARECE), 5),
                    QTCALCNUTRPR = ROUND(((@P_VRVALOR * QTCALCNUTRPR) / @V_SOMARECE), 5)
                  where
                    CDFILAUXPRAT = @V_CDFILAUXPRAT and
                    CDPRATO      = @V_CDPRATO      and
                    ISNULL(IDQTDEFIXPR,'N')  = 'N'       and
                    (QTPRODPRAT   * @P_VRVALOR) >= 0.00001 and
                    (QTBRUTAPR    * @P_VRVALOR) >= 0.00001;
               END;
            END;
         END;
      END;
      IF @P_IDTIPORECE = 'C' BEGIN
      /* Atualiza qtdes da receita conforme valor informado */
         IF @P_IDOPCAO = 'P' BEGIN
            SELECT @V_COUNT = ISNULL(ROUND(SUM(QTPADRAOPRATTP), 5), 0)
            FROM PRATTPCARD
            WHERE
               CDFILAUXPRAT = @V_CDFILAUXPRAT and
               CDPRATO      = @V_CDPRATO and
               CDFILCENTPME = @P_CDFILCENTPME and
               CDTIPOCARD   = @P_CDTIPOCARD;
            IF (@V_COUNT > 0) BEGIN
               update
                  PRATTPCARD
               set
                  QTPADRAOPRATTP = ROUND((ISNULL(QTPADRAOPRATTP, 1) * @P_VRVALOR), 5)
               where
                  CDFILAUXPRAT = @V_CDFILAUXPRAT and
                  CDPRATO      = @V_CDPRATO and
                  CDFILCENTPME = @P_CDFILCENTPME and
                  CDTIPOCARD   = @P_CDTIPOCARD;
              update RECETPCARD
              set
                QTPRODPRATTP   = ROUND(QTPRODPRATTP   * @P_VRVALOR, 5),
                QTUNIDESTPRTP  = ROUND(QTUNIDESTPRTP  * @P_VRVALOR, 5),
                QTBRUTAPRTP    = ROUND(QTBRUTAPRTP    * @P_VRVALOR, 5),
                QTBRUTAPRUNRTP = ROUND(QTBRUTAPRUNRTP * @P_VRVALOR, 5),
                QTCALCNUTRPRTP = ROUND(QTCALCNUTRPRTP * @P_VRVALOR, 5)
              where
                CDFILAUXPRAT = @V_CDFILAUXPRAT and
                CDPRATO      = @V_CDPRATO      and
                CDFILCENTPME = @P_CDFILCENTPME and
                CDTIPOCARD   = @P_CDTIPOCARD and
                ISNULL(IDQTDEFIXPRTP,'N')  = 'N'       and
                (QTPRODPRATTP   * @P_VRVALOR) >= 0.00001 and
                (QTBRUTAPRTP    * @P_VRVALOR) >= 0.00001;
            END;
         END
         ELSE BEGIN
            IF @P_IDOPCAO = 'G' BEGIN
               select @V_SOMARECE = ISNULL(ROUND(SUM(QTPADRAOPRATTP), 5), 0)
               from PRATTPCARD
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO and
                 CDFILCENTPME = @P_CDFILCENTPME and
                 CDTIPOCARD   = @P_CDTIPOCARD;
 
               SELECT @V_COUNTP = COUNT(CDPRATO)
                 FROM PRATTPCARD
                WHERE CDFILAUXPRAT = @V_CDFILAUXPRAT 
                  AND CDPRATO      = @V_CDPRATO 
                  AND CDFILCENTPME = @P_CDFILCENTPME 
                  AND CDTIPOCARD   = @P_CDTIPOCARD;

               IF (@V_COUNTP = 0) BEGIN
                  INSERT INTO PRATTPCARD
                         (CDFILAUXPRAT, CDPRATO, CDFILCENTPME, CDTIPOCARD, QTPADRAOPRATTP)
                  VALUES (@V_CDFILAUXPRAT, @V_CDPRATO, @P_CDFILCENTPME, @P_CDTIPOCARD, ROUND(@P_VRVALOR, 5));
               END
               ELSE BEGIN
                  UPDATE PRATTPCARD
                     SET QTPADRAOPRATTP = ROUND(@P_VRVALOR, 5)
                   WHERE CDFILAUXPRAT = @V_CDFILAUXPRAT 
                     AND CDPRATO      = @V_CDPRATO 
                     AND CDFILCENTPME = @P_CDFILCENTPME 
                     AND CDTIPOCARD   = @P_CDTIPOCARD;
               END;

               IF (@V_SOMARECE > 0) BEGIN
                  update
                     PRATTPCARD
                  set
                     QTPADRAOPRATTP = ROUND(@P_VRVALOR, 5)
                  where
                     CDFILAUXPRAT = @V_CDFILAUXPRAT and
                     CDPRATO      = @V_CDPRATO and
                     CDFILCENTPME = @P_CDFILCENTPME and
                     CDTIPOCARD   = @P_CDTIPOCARD;
                  update RECETPCARD
                  set
                    QTPRODPRATTP   = ROUND(((@P_VRVALOR * QTPRODPRATTP  ) / @V_SOMARECE), 5),
                    QTUNIDESTPRTP  = ROUND(((@P_VRVALOR * QTUNIDESTPRTP ) / @V_SOMARECE), 5),
                    QTBRUTAPRTP    = ROUND(((@P_VRVALOR * QTBRUTAPRTP   ) / @V_SOMARECE), 5),
                    QTBRUTAPRUNRTP = ROUND(((@P_VRVALOR * QTBRUTAPRUNRTP) / @V_SOMARECE), 5),
                    QTCALCNUTRPRTP = ROUND(((@P_VRVALOR * QTCALCNUTRPRTP) / @V_SOMARECE), 5)
                  where
                    CDFILAUXPRAT = @V_CDFILAUXPRAT and
                    CDPRATO      = @V_CDPRATO      and
                    CDFILCENTPME = @P_CDFILCENTPME and
                    CDTIPOCARD   = @P_CDTIPOCARD and
                    ISNULL(IDQTDEFIXPRTP,'N')  = 'N'       and
                    (QTPRODPRATTP * @P_VRVALOR) >= 0.00001 and
                    (QTBRUTAPRTP  * @P_VRVALOR) >= 0.00001;
               END;
            END;
         END;
      END;
      IF @P_IDTIPORECE = 'L' BEGIN
         IF @P_IDOPCAO = 'P' BEGIN
            SELECT @V_COUNT = ISNULL(ROUND(SUM(QTPADRAOFILI), 5), 0)
            FROM PRATFILI
            WHERE
              CDFILAUXPRAT = @V_CDFILAUXPRAT and
              CDPRATO      = @V_CDPRATO      and
              CDFILIAL     = @P_CDFILIAL;
            IF (@V_COUNT > 0) BEGIN
               update
                  PRATFILI
               set
                  QTPADRAOFILI = ROUND((ISNULL(QTPADRAOFILI, 1) * @P_VRVALOR), 5)
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL;
               update RECEFILI
               set
                 QTPRODRECLOC = ROUND(QTPRODRECLOC * @P_VRVALOR, 5),
                 QTUNIDESTLO  = ROUND(QTUNIDESTLO  * @P_VRVALOR, 5),
                 QTBRUTALO    = ROUND(QTBRUTALO    * @P_VRVALOR, 5),
                 QTBRUTALOUNR = ROUND(QTBRUTALOUNR * @P_VRVALOR, 5),
                 QTCALCNUTRLO = ROUND(QTCALCNUTRLO * @P_VRVALOR, 5)
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL         and
                 ISNULL(IDQTDEFIXLO,'N')  = 'N'       and
                 (QTPRODRECLOC * @P_VRVALOR) >= 0.00001 and
                 (QTBRUTALO    * @P_VRVALOR) >= 0.00001;
            END;
         END
         ELSE BEGIN
            IF @P_IDOPCAO = 'G' BEGIN
               select @V_SOMARECE = ISNULL(ROUND(SUM(QTPADRAOFILI), 5), 0)
               from PRATFILI
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL;

               select @V_COUNTP = COUNT(CDPRATO)
               from PRATFILI
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL;

               IF (@V_COUNTP = 0) BEGIN
                  INSERT INTO PRATFILI
                         (CDFILAUXPRAT, CDPRATO, CDFILIAL, QTPADRAOFILI)
                  VALUES (@V_CDFILAUXPRAT, @V_CDPRATO, @P_CDFILIAL, ROUND(@P_VRVALOR, 5));
               END
               ELSE BEGIN
                  UPDATE PRATFILI
                     SET QTPADRAOFILI = ROUND(@P_VRVALOR, 5)
                   WHERE CDFILAUXPRAT = @V_CDFILAUXPRAT 
                     AND CDPRATO      = @V_CDPRATO 
                     AND CDFILIAL     = @P_CDFILIAL;
               END;

               IF (@V_SOMARECE > 0) BEGIN
                  update
                     PRATFILI
                  set
                     QTPADRAOFILI = ROUND(@P_VRVALOR, 5)
                  where
                    CDFILAUXPRAT = @V_CDFILAUXPRAT and
                    CDPRATO      = @V_CDPRATO      and
                    CDFILIAL     = @P_CDFILIAL;
                  update RECEFILI
                  set
                    QTPRODRECLOC = ROUND(((@P_VRVALOR * QTPRODRECLOC) / @V_SOMARECE), 5),
                    QTUNIDESTLO  = ROUND(((@P_VRVALOR * QTUNIDESTLO ) / @V_SOMARECE), 5),
                    QTBRUTALO    = ROUND(((@P_VRVALOR * QTBRUTALO   ) / @V_SOMARECE), 5),
                    QTBRUTALOUNR = ROUND(((@P_VRVALOR * QTBRUTALOUNR) / @V_SOMARECE), 5),
                    QTCALCNUTRLO = ROUND(((@P_VRVALOR * QTCALCNUTRLO) / @V_SOMARECE), 5)
                  where
                    CDFILAUXPRAT = @V_CDFILAUXPRAT and
                    CDPRATO      = @V_CDPRATO      and
                    CDFILIAL     = @P_CDFILIAL         and
                    ISNULL(IDQTDEFIXLO,'N')  = 'N'       and
                    (QTPRODRECLOC * @P_VRVALOR) >= 0.00001 and
                    (QTBRUTALO    * @P_VRVALOR) >= 0.00001;
               END;
            END;
         END;
      END;
      IF @P_IDTIPORECE = 'S' BEGIN
         IF @P_IDOPCAO = 'P' BEGIN
            SELECT @V_COUNT = ISNULL(ROUND(SUM(QTPADRAOSERV), 5), 0)
            FROM PRATSERV
            WHERE
              CDFILAUXPRAT = @V_CDFILAUXPRAT and
              CDPRATO      = @V_CDPRATO      and
              CDFILIAL     = @P_CDFILIAL         and
              CDSERVFILI   = @P_CDSERVFILI;
            IF (@V_COUNT > 0) BEGIN
               update
                  PRATSERV
               set
                  QTPADRAOSERV = ROUND((ISNULL(QTPADRAOSERV, 1) * @P_VRVALOR), 5)
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL         and
                 CDSERVFILI   = @P_CDSERVFILI;
               update RECESERV
               set
                 QTPRODRECSER = ROUND(QTPRODRECSER * @P_VRVALOR, 5),
                 QTUNIDESTSE  = ROUND(QTUNIDESTSE  * @P_VRVALOR, 5),
                 QTBRUTASE    = ROUND(QTBRUTASE    * @P_VRVALOR, 5),
                 QTBRUTASEUNR = ROUND(QTBRUTASEUNR * @P_VRVALOR, 5),
                 QTCALCNUTRSE = ROUND(QTCALCNUTRSE * @P_VRVALOR, 5)
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL         and
                 CDSERVFILI   = @P_CDSERVFILI       and
                 ISNULL(IDQTDEFIXSE,'N')  = 'N'       and
                 (QTPRODRECSER * @P_VRVALOR) >= 0.00001 and
                 (QTBRUTASE    * @P_VRVALOR) >= 0.00001;
            END;
         END
         ELSE BEGIN
            IF @P_IDOPCAO = 'G' BEGIN
               select @V_SOMARECE = ISNULL(ROUND(SUM(QTPADRAOSERV), 5), 0)
               from PRATSERV
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL         and
                 CDSERVFILI   = @P_CDSERVFILI;

               select @V_COUNTP = COUNT(CDPRATO)
               from PRATSERV
               where
                 CDFILAUXPRAT = @V_CDFILAUXPRAT and
                 CDPRATO      = @V_CDPRATO      and
                 CDFILIAL     = @P_CDFILIAL     and
                 CDSERVFILI   = @P_CDSERVFILI;

               IF (@V_COUNTP = 0) BEGIN
                  INSERT INTO PRATSERV
                         (CDFILAUXPRAT, CDPRATO, CDFILIAL, CDSERVFILI, QTPADRAOSERV)
                  VALUES (@V_CDFILAUXPRAT, @V_CDPRATO, @P_CDFILIAL, @P_CDSERVFILI, ROUND(@P_VRVALOR, 5));
               END
               ELSE BEGIN
                  UPDATE PRATSERV
                     SET QTPADRAOSERV = ROUND(@P_VRVALOR, 5)
                   WHERE CDFILAUXPRAT = @V_CDFILAUXPRAT 
                     AND CDPRATO      = @V_CDPRATO 
                     AND CDFILIAL     = @P_CDFILIAL
                     AND CDSERVFILI   = @P_CDSERVFILI;
               END;

               IF (@V_SOMARECE > 0) BEGIN
                  update
                     PRATSERV
                  set
                     QTPADRAOSERV = ROUND(@P_VRVALOR, 5)
                  where
                    CDFILAUXPRAT = @V_CDFILAUXPRAT and
                    CDPRATO      = @V_CDPRATO      and
                    CDFILIAL     = @P_CDFILIAL         and
                    CDSERVFILI   = @P_CDSERVFILI;
                  update RECESERV
                  set
                    QTPRODRECSER = ROUND(((@P_VRVALOR * QTPRODRECSER) / @V_SOMARECE), 5),
                    QTUNIDESTSE  = ROUND(((@P_VRVALOR * QTUNIDESTSE ) / @V_SOMARECE), 5),
                    QTBRUTASE    = ROUND(((@P_VRVALOR * QTBRUTASE   ) / @V_SOMARECE), 5),
                    QTBRUTASEUNR = ROUND(((@P_VRVALOR * QTBRUTASEUNR) / @V_SOMARECE), 5),
                    QTCALCNUTRSE = ROUND(((@P_VRVALOR * QTCALCNUTRSE) / @V_SOMARECE), 5)
                  where
                    CDFILAUXPRAT = @V_CDFILAUXPRAT and
                    CDPRATO      = @V_CDPRATO      and
                    CDFILIAL     = @P_CDFILIAL         and
                    CDSERVFILI   = @P_CDSERVFILI       and
                    ISNULL(IDQTDEFIXSE,'N')  = 'N'       and
                    (QTPRODRECSER * @P_VRVALOR) >= 0.00001 and
                    (QTBRUTASE    * @P_VRVALOR) >= 0.00001;
               END;
            END;
         END;
      END;
      FETCH NEXT FROM C_LST INTO @V_CDPRATO, @V_CDFILAUXPRAT;
   END;
   CLOSE C_LST;
   DEALLOCATE C_LST;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'REVISA_QTDE','5.09.000';
GO